==> qtjambi-httpserver-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiHttpServer/QHttpServer_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHttpServer/qhttpserver.h>
#include <QtCore/QVariant>
#include <QtCore/qobject.h>
#include <QtHttpServer/qhttpserverrouter.h>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtHttpServer/qhttpserverresponse.h>
#include <qconfig.h>
#if QT_CONFIG(future)
#include <QtCore/qfuture.h>
#endif //QT_CONFIG(future)
#include <QtCore/QList>
#include <QtNetwork/qtcpserver.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslkey.h>
#include <QtNetwork/qssl.h>
#include <QtWebSockets/qwebsocket.h>
#include <QtNetwork/qsslconfiguration.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qtimer.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qvariant.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qthread.h>
#include <QtCore/qproperty.h>
#include <QtCore/qbindingstorage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/JavaAPI>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// new QHttpServer(QObject*)
void __qt_construct_QHttpServer_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttpServer(QObject*)")
    Q_UNUSED(__java_arguments)
    QHttpServer *__qt_this = new(__qtjambi_ptr) QHttpServer();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHttpServer(QObject*)
void __qt_construct_QHttpServer_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttpServer(QObject*)")
    jobject parent0 = __java_arguments[0].l;
    QObject* __qt_parent0 = qtjambi_cast<QObject* >(__jni_env, parent0);
    QtJambiAPI::checkThreadOnParent(__jni_env, __qt_parent0);
    QHttpServer *__qt_this = new(__qtjambi_ptr) QHttpServer(__qt_parent0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QHttpServer
void __qt_destruct_QHttpServer(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHttpServer")
    reinterpret_cast<QHttpServer*>(ptr)->~QHttpServer();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHttpServer::QHttpServer(QObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_httpserver_QHttpServer_initialize_1native__Lio_qt_httpserver_QHttpServer_2Lio_qt_core_QObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject parent0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHttpServer::QHttpServer(QObject*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = parent0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHttpServer_1, sizeof(QHttpServer), typeid(QHttpServer), QHttpServer::staticMetaObject, false, false, false, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHttpServer::router()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_httpserver_QHttpServer_router_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHttpServer *__qt_this = QtJambiAPI::objectFromNativeId<QHttpServer>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttpServer::router()", __qt_this)
        QHttpServerRouter* __qt_return_value = __qt_this->router();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHttpServer::setMissingHandler(QHttpServer::MissingHandler)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_httpserver_QHttpServer_setMissingHandler_1native_1QHttpServer_1MissingHandler__JLio_qt_httpserver_QHttpServer_00024MissingHandler_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject handler0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHttpServer *__qt_this = QtJambiAPI::objectFromNativeId<QHttpServer>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttpServer::setMissingHandler(QHttpServer::MissingHandler)", __qt_this)
        QHttpServer::MissingHandler __qt_handler0 = qtjambi_cast<QHttpServer::MissingHandler>(__jni_env, handler0);
        __qt_this->setMissingHandler(__qt_handler0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHttpServer(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHttpServer>("QHttpServer", "io/qt/httpserver/QHttpServer");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHttpServer, {
        ConstructorInfo(&__qt_construct_QHttpServer_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHttpServer_1, "Lio/qt/core/QObject;")
    });
// END: function table

    registerMetaObject(typeId, QHttpServer::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-httpserver-debuginfo-linux-x64-6.6.2.jar: sources/QtJambiHttpServer/QHttpServer_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHttpServer/qhttpserver.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <qconfig.h>
#if QT_CONFIG(future)
#include <QtCore/qfuture.h>
#endif //QT_CONFIG(future)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtHttpServer/qhttpserverresponse.h>
#include <QtHttpServer/qhttpserverrouter.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qssl.h>
#if __has_include(<QtNetwork/qsslcertificate.h>)
#include <QtNetwork/qsslcertificate.h>
#endif
#if __has_include(<QtNetwork/qsslconfiguration.h>)
#include <QtNetwork/qsslconfiguration.h>
#endif
#if __has_include(<QtNetwork/qsslkey.h>)
#include <QtNetwork/qsslkey.h>
#endif
#include <QtNetwork/qtcpserver.h>
#include <QtWebSockets/qwebsocket.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/JavaAPI>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// new QHttpServer(QObject*)
void __qt_construct_QHttpServer(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttpServer(QObject*)")
    Q_UNUSED(__java_arguments)
    QHttpServer *__qt_this = new(__qtjambi_ptr) QHttpServer();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHttpServer(QObject*)
void __qt_construct_QHttpServer_QObject_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHttpServer(QObject*)")
    jobject parent0 = __java_arguments[0].l;
    QObject* __qt_parent0 = qtjambi_cast<QObject* >(__jni_env, parent0);
    QtJambiAPI::checkThreadOnParent(__jni_env, __qt_parent0);
    QHttpServer *__qt_this = new(__qtjambi_ptr) QHttpServer(__qt_parent0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHttpServer::QHttpServer(QObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_httpserver_QHttpServer_initialize_1native__Lio_qt_httpserver_QHttpServer_2Lio_qt_core_QObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject parent0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHttpServer::QHttpServer(QObject*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = parent0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHttpServer_QObject_ptr, sizeof(QHttpServer), typeid(QHttpServer), QHttpServer::staticMetaObject, false, false, false, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QHttpServer
void __qt_destruct_QHttpServer(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHttpServer")
    reinterpret_cast<QHttpServer*>(ptr)->~QHttpServer();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHttpServer::router()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_httpserver_QHttpServer_router_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHttpServer *__qt_this = QtJambiAPI::objectFromNativeId<QHttpServer>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttpServer::router()", __qt_this)
        QHttpServerRouter* __qt_return_value = __qt_this->router();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QHttpServer::setMissingHandler(QHttpServer::MissingHandler)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_httpserver_QHttpServer_setMissingHandler_1native_1QHttpServer_1MissingHandler__JLio_qt_httpserver_QHttpServer_00024MissingHandler_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject handler0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QHttpServer *__qt_this = QtJambiAPI::objectFromNativeId<QHttpServer>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHttpServer::setMissingHandler(QHttpServer::MissingHandler)", __qt_this)
        QHttpServer::MissingHandler __qt_handler0 = qtjambi_cast<QHttpServer::MissingHandler>(__jni_env, handler0);
        __qt_this->setMissingHandler(__qt_handler0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QHttpServer(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHttpServer>("QHttpServer", "io/qt/httpserver/QHttpServer");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHttpServer, {
        ConstructorInfo(&__qt_construct_QHttpServer, nullptr)
       ,ConstructorInfo(&__qt_construct_QHttpServer_QObject_ptr, "Lio/qt/core/QObject;")
    });
// END: function table

    registerMetaObject(typeId, QHttpServer::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
